==> moodle_1.3.1.orig.tar.gz: moodle/lang/cs/survey.php <==
<?PHP // $Id: survey.php,v 1.2 2004/05/28 01:18:30 mudrd8mz Exp $ 
      // survey.php - created with Moodle 1.3 (2004052500)


$string['actual'] = 'Aktuln';
$string['actualclass'] = 'Aktuln tda';
$string['actualstudent'] = '$a aktualn';
$string['allquestions'] = 'Vechny otzky v poad, vichni studenti';
$string['allscales'] = 'Vechny kly, vichni studenti';
$string['alreadysubmitted'] = 'Ji jste vyplnil tento dotaznk';
$string['analysisof'] = 'Rozbor - $a';
$string['answers'] = 'Odpovdi';
$string['attls1'] = 'Kdy hodnotm n vrok, zamuji se na to, CO je eeno, ne na to, KDO to k.';
$string['attls10'] = 'Kdy nco rozebrm, je pro m dleit zstat co nejobjektivnj.';
$string['attls10short'] = 'zstat objektivn';
$string['attls11'] = 'Snam se pemlet v souladu v dalmi lidmi, ne proti nim.';
$string['attls11short'] = 'pemlet v souladu s ostatnmi';
$string['attls12'] = 'Mm urit kritria, kter pouvm pi hodnocen argument.';
$string['attls12short'] = 'pouit kritri pi hodnocen';
$string['attls13'] = 'Snam se sp chpat nzory ostatnch, ne je hodnotit.';
$string['attls13short'] = 'snaha o pochopen';
$string['attls14'] = 'Poukazuju na slab msta v mylen jinch a snam se jim tak pomoci, aby si sami ujasnili sv argumenty.';
$string['attls14short'] = 'poukazovn na slab msta';
$string['attls15'] = 'Pi diskusi o kontroverznm tmatu mm sklon pedstavovat si sm sebe v ki druhch, abych pochopil, pro pemlej tak, jak pemlej.';
$string['attls15short'] = 'vctn se do ke jinch';
$string['attls16'] = 'Mj zpsob analyzovn vc je podobn soudnmu pelen, protoe peliv zvauju vechny dkazy.';
$string['attls16short'] = 'soudn pelen';
$string['attls17'] = 'Pi een problm si cenm pouvn logiky a rozumu namsto zohledovn vlastnch zjm.';
$string['attls17short'] = 'oceuji logiku';
$string['attls18'] = 'Dky empatii se umm vctit a zskat vhled do nzor, kter se li od tch mch.';
$string['attls18short'] = 'vhled dky empatii';
$string['attls19'] = 'Kdy se stetnu s lovkem, jeho nzory se mi zdaj ciz, snam se mysln vt do jeho situace, abych pochopil dvody pro tyto nzory.';
$string['attls19short'] = 'snaha vctit se';
$string['attls1short'] = 'zamen se na obsah sdlen';
$string['attls2'] = 'Rd si hraju na blova advokta - tvrdm opak toho, co k ten druh.';
$string['attls20'] = 'Trvm as tm, e zjiuji, kde je problm. Napklad to, co nen vysvtleno dostaten pesvdiv, si dohledm v odborn literatue.';
$string['attls20short'] = 'kde je problm';
$string['attls2short'] = 'hra na blova advokta';
$string['attls3'] = 'Zajm m, \'odkud pichzej\' jin lid, jak zkuenosti je vedly k tomu, e se ct tak, jak se ct.';
$string['attls3short'] = 'odkud pichzej';
$string['attls4'] = 'Nejdleitj st mho vzdlvn je uit se porozumt lidem, kte jsou ode m velmi odlin.';
$string['attls4short'] = 'porozumt odlinm lidem';
$string['attls5'] = 'Mm pocit, e nejlep zpsob, jak porozumt sm sob, je stetvat se s mnostvm rznch lid.';
$string['attls5short'] = 'stetvn se s rznost';
$string['attls6'] = 'Rd poslouchm nzory jinch lid, kte pichzej z odlinho prosted. Pomh mi to pochopit, jak me bt jedna vc nazrna rznmi zpsoby.';
$string['attls6short'] = 'vyslyen nzor';
$string['attls7'] = 'Zjiuji, e svou vlastn pozici si mu upevnit tm, e diskutuju s nkm, kdo se mnou nesouhlas.';
$string['attls7short'] = 'upevnn diskus';
$string['attls8'] = 'Vdycky rd poznvm, pro lid kaj a v v jist vci.';
$string['attls8short'] = 'vdt, pro to lid dlaj';
$string['attls9'] = 'asto se pistihnu, jak se dohaduju s autory knih, kter tu, a logicky vysvtluju, pro se ml.';
$string['attls9short'] = 'dohadovn se s autory';
$string['attlsintro'] = 'Clem tohoto dotaznku je pomoci nm vyhodnotit vae postoje k mylen a uen se.<P>Nejsou zde dn \'sprvn\' nebo \'patn\' odpovdi, zajm ns pouze v nzor. Prosm, bute si jist, e s vaimi odpovmi budeme nakldat velice dvrn a dnm zpsobem neovlivn vae hodnocen.';
$string['attlsm1'] = 'Postoje k mylen a uen se (ATTL)';
$string['attlsm2'] = 'Kolektivn uen se';
$string['attlsm3'] = 'Individuln uen se';
$string['attlsmintro'] = 'V diskusi ...';
$string['attlsname'] = 'ATTLS (verze s 20 polokami)';
$string['ciq1'] = 'Kter okamik vs jako ka ve td nejvce zaujal?';
$string['ciq1short'] = 'Nejvc zaujalo';
$string['ciq2'] = 'Kter okamk vm byl jako kovi ve td nejvc nepjemn?';
$string['ciq2short'] = 'Nejvc nepjemn';
$string['ciq3'] = 'Co vm nejvce pomhalo pi komunikaci (s kmkoliv) v diskusnch frech?';
$string['ciq3short'] = 'Nejvc pomhalo';
$string['ciq4'] = 'Co vs nejvce mtlo nebo uvdlo do rozpak pi komunikaci (s kmkoliv) v diskusnch frech?';
$string['ciq4short'] = 'Nejvc mtlo';
$string['ciq5'] = 'Jak udlost vs nejvce pekvapila?';
$string['ciq5short'] = 'Pekvapen';
$string['ciqintro'] = 'Popemlejte o prbhu vuky minul tden a zodpovzte nsledujc otzky.';
$string['ciqname'] = 'Dleit okamiky (Critical Incidents)';
$string['clicktocontinue'] = 'Stisknte pro pokraovn';
$string['clicktocontinuecheck'] = 'Stiskte pro odevzdn';
$string['colles1'] = 'se pi uen zamuju na tmata, kter m zajmaj';
$string['colles10'] = 'dm ostatn spoluky, aby objasnili sv mylenky a npady.';
$string['colles10short'] = 'dm objasnn';
$string['colles11'] = 'ostatn spoluci m daj o objasnn mch mylenek a npad.';
$string['colles11short'] = 'jsem dn o objasnn';
$string['colles12'] = 'ostatn spoluci reaguj na m npady a mylenky.';
$string['colles12short'] = 'spoluci na mn reaguj';
$string['colles13'] = 'm uitel podncuje k pemlen';
$string['colles13short'] = 'uitel m podncuje';
$string['colles14'] = 'm uitel povzbuzuje k zapojen se.';
$string['colles14short'] = 'uitel m povzbuzuje';
$string['colles15'] = 'uitel rozpoutv kvalitn rozpravu.';
$string['colles15short'] = 'uitel rozpoutv rozpravu';
$string['colles16'] = 'uitel je schopen kritickho sebehodnocen.';
$string['colles16short'] = 'uitel je schopen sebehodnocen';
$string['colles17'] = 'm dal spoluci povzbuzuj v zapojovn se.';
$string['colles17short'] = 'spoluci m povzbuzuj';
$string['colles18'] = 'spoluci kladn hodnot m pspvky.';
$string['colles18short'] = 'spoluci m kladn hodnot';
$string['colles19'] = 'si spoluci cen mch pipomnek.';
$string['colles19short'] = 'spoluci si m cen';
$string['colles1short'] = 'zamuji se na zajmav tmata';
$string['colles2'] = 'se um to, co se me hodit v praxi.';
$string['colles20'] = 'spoluci dovedou pochopit m nesnze s uenm.';
$string['colles20short'] = 'spoluci dovedou pochopit';
$string['colles21'] = 'rozumm tomu, co sdluj m spoluci.';
$string['colles21short'] = 'rozumm spolukm';
$string['colles22'] = 'spoluci rozum tomu, co km.';
$string['colles22short'] = 'spoluci mi rozum';
$string['colles23'] = 'rozumm tomu, co sdluje uitel.';
$string['colles23short'] = 'rozumm uiteli';
$string['colles24'] = 'uitel rozum tomu, co km.';
$string['colles24short'] = 'uitel mi rozum';
$string['colles2short'] = 'pouitelnost v praxi';
$string['colles3'] = 'se um, jak zlepit m profesn i praktick dovednosti.';
$string['colles3short'] = 'zdokonalit se v profesi';
$string['colles4'] = 'to, co se um, souvis s mou profes i prax.';
$string['colles4short'] = 'souvislost s profes';
$string['colles5'] = 'vn pemlm o tom, jak se um.';
$string['colles5short'] = 'jsem kritick k uen';
$string['colles6'] = 'vn pemlm o mch npadech.';
$string['colles6short'] = 'jsem kritick k vlastnm npadm';
$string['colles7'] = 'vn pemlm o npadech mch spoluk.';
$string['colles7short'] = 'jsem kritick ke spolukm';
$string['colles8'] = 'pi ten vn pemlm o sdlovanch mylenkch.';
$string['colles8short'] = 'jsem kritick k textm';
$string['colles9'] = 'objasuji sv npady a mylenky spolukm.';
$string['colles9short'] = 'objasuji sv mylenky';
$string['collesaintro'] = 'Clem tohoto dotaznku je zjistit, jak dobe se vm pracovalo a uilo v tomto online prosted. <P>Kad z nsledujcch 24 otzek se pt na vae momentln zkuenosti s tmto kurzem. <P>Nejsou zde dn \'sprvn\' nebo \'patn\' odpovdi, zajm ns pouze v nzor. Prosm, bute si jist, e s vaimi odpovmi budeme nakldat velice dvrn a dnm zpsobem neovlivn vae hodnocen.<P>Dkujeme za peliv a uven vyplnn tohoto dotaznku. Vae odpovdi nm pomohou vylepit online vuku tohoto kurzu v budoucnosti.';
$string['collesaname'] = 'COLLES (Zkuenosti)';
$string['collesapintro'] = 'Clem tohoto dotaznku je zjistit, jak se vm pracovalo a uilo v tomto online prosted. <P>V kad z nsledujcch 24 otzek srovnejte vae <B>ideln pedstavy</B> a <B>momentln zkuenosti</B> s tmto kurzem.  <P>Nejsou zde dn \'sprvn\' nebo \'patn\' odpovdi, zajm ns pouze v nzor. Prosm, bute si jist, e s vaimi odpovmi budeme nakldat velice dvrn a dnm zpsobem neovlivn vae hodnocen.<P>Dkujeme za peliv a uven vyplnn tohoto dotaznku. Vae odpovdi nm pomohou vylepit online vuku tohoto kurzu v budoucnosti.';
$string['collesapname'] = 'COLLES (Pedstavy/Zkuenosti)';
$string['collesm1'] = 'Zvanost';
$string['collesm1short'] = 'Zvanost';
$string['collesm2'] = 'Reflektujc uvaovn';
$string['collesm2short'] = 'Reflektujc uvaovn';
$string['collesm3'] = 'Interaktivita';
$string['collesm3short'] = 'Interaktivita';
$string['collesm4'] = 'Podpora uitele';
$string['collesm4short'] = 'Podpora uitele';
$string['collesm5'] = 'Podpora spoluk';
$string['collesm5short'] = 'Podpora spoluk';
$string['collesm6'] = 'Interpratace';
$string['collesm6short'] = 'Interpretace';
$string['collesmintro'] = 'V tomto online kurzu...';
$string['collespintro'] = 'Clem tohoto dotaznku je zjistit, eho si cente na prci a uen se v online prosted. <P>Kad z nsledujcch 24 otzek se pt na vae <B>ideln pedstavy</B> o tomto kurzu. <P>Nejsou zde dn \'sprvn\' nebo \'patn\' odpovdi, zajm ns pouze v nzor. Prosm, bute si jist, e s vaimi odpovmi budeme nakldat velice dvrn a dnm zpsobem neovlivn vae hodnocen.<P>Dkujeme za peliv a uven vyplnn tohoto dotaznku. Vae odpovdi nm pomohou vylepit online vuku tohoto kurzu v budoucnosti.';
$string['collespname'] = 'COLLES (Pedstavy)';
$string['done'] = 'Hotovo';
$string['download'] = 'Sthnout';
$string['downloadexcel'] = 'Sthnout data ve formtu tabulky Excel';
$string['downloadinfo'] = 'Mte monost sthnout daje zjitn tmto dotaznkem pro dal zpracovn v Excelu, SPSS nebo jinm programu.';
$string['downloadtext'] = 'Sthnout jako obyejn textov soubor';
$string['editingasurvey'] = 'prava dotaznku';
$string['guestsnotallowed'] = 'Hostm nen dovoleno vyplovat dotaznky';
$string['helpsurveys'] = 'Npovda k rznm typm dotaznk';
$string['howlong'] = 'Jak dlouho vm trvalo vyplnn tohoto dotanku?';
$string['howlongoptions'] = 'mn ne 1 minutu,1-2 minuty,2-3 minuty,3-4 minuty,4-5-minut,5-10 minut,vce ne 10 minut';
$string['ifoundthat'] = 'Zjistil jsem, e';
$string['introtext'] = 'vodn text';
$string['ipreferthat'] = 'Pedstavoval bych si, e';
$string['modulename'] = 'Dotaznk';
$string['modulenameplural'] = 'Dotaznky';
$string['name'] = 'Jmno';
$string['newsurveyresponses'] = 'Nov vyplnn dotaznky';
$string['nobodyyet'] = 'Dosud nikdo nevyplnil tento dotaznk';
$string['notdone'] = 'Zatm nedokoneo';
$string['notes'] = 'Vae soukrom postehy a poznmky';
$string['othercomments'] = 'Mte njak dal pipomnky?';
$string['peoplecompleted'] = '$a zatm vyplnilo tento dotaznk';
$string['preferred'] = 'Pedstavy';
$string['preferredclass'] = 'Cel tda - pedstavy';
$string['preferredstudent'] = '$a - pedstavy';
$string['question'] = 'Otzka';
$string['questions'] = 'Otzky';
$string['questionsnotanswered'] = 'Nebyly zodpovzeny nkter otzky.';
$string['report'] = 'Vsledky dotazovn';
$string['savednotes'] = 'Vae poznmky byly uloeny';
$string['scaleagree5'] = 'Zcela nesouhlasm,sten nesouhlasm,Nemohu ci,sten souhlasm,Zcela souhlasm';
$string['scales'] = 'kly';
$string['scaletimes5'] = 'Tm nikdy,Zdka,Nkdy,asto,Tm vdy';
$string['seemoredetail'] = 'Vce podrobnost...';
$string['selectedquestions'] = 'Vybran odpovdi ze kly, vichni ci';
$string['summary'] = 'Souhrn';
$string['surveycompleted'] = 'Tento dotaznk jste ji vyplnili. Nsledujc graf zobrazuje souhrn vaich odpovd ve srovnn s prmrem cel tdy.';
$string['surveyname'] = 'Nzev dotaznku';
$string['surveysaved'] = 'Dotaznk uloen';
$string['surveytype'] = 'Typ dotaznku';
$string['thanksforanswers'] = 'Dkujeme za vyplnn tohoto dotaznku, $a';
$string['time'] = 'as';
$string['viewsurveyresponses'] = 'Zobrazit $a vyplnnch odpovd';

?>

==> moodle_1.4.4.dfsg.1.orig.tar.gz: moodle/lang/cs/survey.php <==
<?PHP // $Id$ 
      // survey.php - created with Moodle 1.4 (2004083100)


$string['actual'] = 'Aktuln';
$string['actualclass'] = 'Aktuln tda';
$string['actualstudent'] = '$a aktualn';
$string['allquestions'] = 'Vechny otzky v poad, vichni studenti';
$string['allscales'] = 'Vechny kly, vichni studenti';
$string['alreadysubmitted'] = 'Ji jste odpovdali v tomto przkumu';
$string['analysisof'] = 'Rozbor - $a';
$string['answers'] = 'Odpovdi';
$string['attls1'] = 'Kdy hodnotm n vrok, zamuji se na to, CO je eeno, ne na to, KDO to k.';
$string['attls10'] = 'Kdy nco rozebrm, je pro m dleit zstat co nejobjektivnj.';
$string['attls10short'] = 'zstat objektivn';
$string['attls11'] = 'Snam se pemlet v souladu v dalmi lidmi, ne proti nim.';
$string['attls11short'] = 'pemlet v souladu s ostatnmi';
$string['attls12'] = 'Mm urit kritria, kter pouvm pi hodnocen argument.';
$string['attls12short'] = 'pouit kritri pi hodnocen';
$string['attls13'] = 'Snam se sp chpat nzory ostatnch, ne je hodnotit.';
$string['attls13short'] = 'snaha o pochopen';
$string['attls14'] = 'Poukazuju na slab msta v mylen jinch a snam se jim tak pomoci, aby si sami ujasnili sv argumenty.';
$string['attls14short'] = 'poukazovn na slab msta';
$string['attls15'] = 'Pi diskusi o kontroverznm tmatu mm sklon pedstavovat si sm sebe v ki druhch, abych pochopil, pro pemlej tak, jak pemlej.';
$string['attls15short'] = 'vctn se do ke jinch';
$string['attls16'] = 'Mj zpsob analyzovn vc je podobn soudnmu pelen, protoe peliv zvauju vechny dkazy.';
$string['attls16short'] = 'soudn pelen';
$string['attls17'] = 'Pi een problm si cenm pouvn logiky a rozumu namsto zohledovn vlastnch zjm.';
$string['attls17short'] = 'oceuji logiku';
$string['attls18'] = 'Dky empatii se umm vctit a zskat vhled do nzor, kter se li od tch mch.';
$string['attls18short'] = 'vhled dky empatii';
$string['attls19'] = 'Kdy se stetnu s lovkem, jeho nzory se mi zdaj ciz, snam se mysln vt do jeho situace, abych pochopil dvody pro tyto nzory.';
$string['attls19short'] = 'snaha vctit se';
$string['attls1short'] = 'zamen se na obsah sdlen';
$string['attls2'] = 'Rd si hraju na blova advokta - tvrdm opak toho, co k ten druh.';
$string['attls20'] = 'Trvm as tm, e zjiuji, kde je problm. Napklad to, co nen vysvtleno dostaten pesvdiv, si dohledm v odborn literatue.';
$string['attls20short'] = 'kde je problm';
$string['attls2short'] = 'hra na blova advokta';
$string['attls3'] = 'Zajm m, \'odkud pichzej\' jin lid, jak zkuenosti je vedly k tomu, e se ct tak, jak se ct.';
$string['attls3short'] = 'odkud pichzej';
$string['attls4'] = 'Nejdleitj st mho vzdlvn je uit se porozumt lidem, kte jsou ode m velmi odlin.';
$string['attls4short'] = 'porozumt odlinm lidem';
$string['attls5'] = 'Mm pocit, e nejlep zpsob, jak porozumt sm sob, je stetvat se s mnostvm rznch lid.';
$string['attls5short'] = 'stetvn se s rznost';
$string['attls6'] = 'Rd poslouchm nzory jinch lid, kte pichzej z odlinho prosted. Pomh mi to pochopit, jak me bt jedna vc nazrna rznmi zpsoby.';
$string['attls6short'] = 'vyslyen nzor';
$string['attls7'] = 'Zjiuji, e svou vlastn pozici si mu upevnit tm, e diskutuju s nkm, kdo se mnou nesouhlas.';
$string['attls7short'] = 'upevnn diskus';
$string['attls8'] = 'Vdycky rd poznvm, pro lid kaj a v v jist vci.';
$string['attls8short'] = 'vdt, pro to lid dlaj';
$string['attls9'] = 'asto se pistihnu, jak se dohaduju s autory knih, kter tu, a logicky vysvtluju, pro se ml.';
$string['attls9short'] = 'dohadovn se s autory';
$string['attlsintro'] = 'Clem tohoto dotaznku je pomoci nm vyhodnotit vae postoje k mylen a uen se.<P>Nejsou zde dn \'sprvn\' nebo \'patn\' odpovdi, zajm ns pouze v nzor. Prosm, bute si jist, e s vaimi odpovmi budeme nakldat velice dvrn a dnm zpsobem neovlivn vae hodnocen.';
$string['attlsm1'] = 'Postoje k mylen a uen se (ATTL)';
$string['attlsm2'] = 'Kolektivn uen se';
$string['attlsm3'] = 'Individuln uen se';
$string['attlsmintro'] = 'V diskusi ...';
$string['attlsname'] = 'ATTLS (verze s 20 polokami)';
$string['ciq1'] = 'Kter okamik vs jako ka ve td nejvce zaujal?';
$string['ciq1short'] = 'Nejvc zaujalo';
$string['ciq2'] = 'Kter okamk vm byl jako kovi ve td nejvc nepjemn?';
$string['ciq2short'] = 'Nejvc nepjemn';
$string['ciq3'] = 'Co vm nejvce pomhalo pi komunikaci (s kmkoliv) v diskusnch frech?';
$string['ciq3short'] = 'Nejvc pomhalo';
$string['ciq4'] = 'Co vs nejvce mtlo nebo uvdlo do rozpak pi komunikaci (s kmkoliv) v diskusnch frech?';
$string['ciq4short'] = 'Nejvc mtlo';
$string['ciq5'] = 'Jak udlost vs nejvce pekvapila?';
$string['ciq5short'] = 'Pekvapen';
$string['ciqintro'] = 'Popemlejte o prbhu vuky minul tden a zodpovzte nsledujc otzky.';
$string['ciqname'] = 'Dleit okamiky (Critical Incidents)';
$string['clicktocontinue'] = 'Stisknte pro pokraovn';
$string['clicktocontinuecheck'] = 'Stiskte pro odevzdn';
$string['colles1'] = 'se pi uen zamuju na tmata, kter m zajmaj';
$string['colles10'] = 'dm ostatn spoluky, aby objasnili sv mylenky a npady.';
$string['colles10short'] = 'dm objasnn';
$string['colles11'] = 'ostatn spoluci m daj o objasnn mch mylenek a npad.';
$string['colles11short'] = 'jsem dn o objasnn';
$string['colles12'] = 'ostatn spoluci reaguj na m npady a mylenky.';
$string['colles12short'] = 'spoluci na mn reaguj';
$string['colles13'] = 'm uitel podncuje k pemlen';
$string['colles13short'] = 'uitel m podncuje';
$string['colles14'] = 'm uitel povzbuzuje k zapojen se.';
$string['colles14short'] = 'uitel m povzbuzuje';
$string['colles15'] = 'uitel rozpoutv kvalitn rozpravu.';
$string['colles15short'] = 'uitel rozpoutv rozpravu';
$string['colles16'] = 'uitel je schopen kritickho sebehodnocen.';
$string['colles16short'] = 'uitel je schopen sebehodnocen';
$string['colles17'] = 'm dal spoluci povzbuzuj v zapojovn se.';
$string['colles17short'] = 'spoluci m povzbuzuj';
$string['colles18'] = 'spoluci kladn hodnot m pspvky.';
$string['colles18short'] = 'spoluci m kladn hodnot';
$string['colles19'] = 'si spoluci cen mch pipomnek.';
$string['colles19short'] = 'spoluci si m cen';
$string['colles1short'] = 'zamuji se na zajmav tmata';
$string['colles2'] = 'se um to, co se me hodit v praxi.';
$string['colles20'] = 'spoluci dovedou pochopit m nesnze s uenm.';
$string['colles20short'] = 'spoluci dovedou pochopit';
$string['colles21'] = 'rozumm tomu, co sdluj m spoluci.';
$string['colles21short'] = 'rozumm spolukm';
$string['colles22'] = 'spoluci rozum tomu, co km.';
$string['colles22short'] = 'spoluci mi rozum';
$string['colles23'] = 'rozumm tomu, co sdluje uitel.';
$string['colles23short'] = 'rozumm uiteli';
$string['colles24'] = 'uitel rozum tomu, co km.';
$string['colles24short'] = 'uitel mi rozum';
$string['colles2short'] = 'pouitelnost v praxi';
$string['colles3'] = 'se um, jak zlepit m profesn i praktick dovednosti.';
$string['colles3short'] = 'zdokonalit se v profesi';
$string['colles4'] = 'to, co se um, souvis s mou profes i prax.';
$string['colles4short'] = 'souvislost s profes';
$string['colles5'] = 'vn pemlm o tom, jak se um.';
$string['colles5short'] = 'jsem kritick k uen';
$string['colles6'] = 'vn pemlm o mch npadech.';
$string['colles6short'] = 'jsem kritick k vlastnm npadm';
$string['colles7'] = 'vn pemlm o npadech mch spoluk.';
$string['colles7short'] = 'jsem kritick ke spolukm';
$string['colles8'] = 'pi ten vn pemlm o sdlovanch mylenkch.';
$string['colles8short'] = 'jsem kritick k textm';
$string['colles9'] = 'objasuji sv npady a mylenky spolukm.';
$string['colles9short'] = 'objasuji sv mylenky';
$string['collesaintro'] = 'Clem tohoto dotaznku je zjistit, jak dobe se vm pracovalo a uilo v tomto online prosted. <P>Kad z nsledujcch 24 otzek se pt na vae momentln zkuenosti s tmto kurzem. <P>Nejsou zde dn \'sprvn\' nebo \'patn\' odpovdi, zajm ns pouze v nzor. Prosm, bute si jist, e s vaimi odpovmi budeme nakldat velice dvrn a dnm zpsobem neovlivn vae hodnocen.<P>Dkujeme za peliv a uven vyplnn tohoto dotaznku. Vae odpovdi nm pomohou vylepit online vuku tohoto kurzu v budoucnosti.';
$string['collesaname'] = 'COLLES (Zkuenosti)';
$string['collesapintro'] = 'Clem tohoto dotaznku je zjistit, jak se vm pracovalo a uilo v tomto online prosted. <P>V kad z nsledujcch 24 otzek srovnejte vae <B>ideln pedstavy</B> a <B>momentln zkuenosti</B> s tmto kurzem.  <P>Nejsou zde dn \'sprvn\' nebo \'patn\' odpovdi, zajm ns pouze v nzor. Prosm, bute si jist, e s vaimi odpovmi budeme nakldat velice dvrn a dnm zpsobem neovlivn vae hodnocen.<P>Dkujeme za peliv a uven vyplnn tohoto dotaznku. Vae odpovdi nm pomohou vylepit online vuku tohoto kurzu v budoucnosti.';
$string['collesapname'] = 'COLLES (Pedstavy/Zkuenosti)';
$string['collesm1'] = 'Zvanost';
$string['collesm1short'] = 'Zvanost';
$string['collesm2'] = 'Reflektujc uvaovn';
$string['collesm2short'] = 'Reflektujc uvaovn';
$string['collesm3'] = 'Interaktivita';
$string['collesm3short'] = 'Interaktivita';
$string['collesm4'] = 'Podpora uitele';
$string['collesm4short'] = 'Podpora uitele';
$string['collesm5'] = 'Podpora spoluk';
$string['collesm5short'] = 'Podpora spoluk';
$string['collesm6'] = 'Interpratace';
$string['collesm6short'] = 'Interpretace';
$string['collesmintro'] = 'V tomto online kurzu...';
$string['collespintro'] = 'Clem tohoto przkumu je zjistit, eho si cente na prci a uen se v online prosted. <P>Kad z nsledujcch 24 otzek se pt na vae <B>ideln pedstavy</B> o tomto kurzu. <P>Nejsou zde dn \'sprvn\' nebo \'patn\' odpovdi, zajm ns pouze v nzor. Prosm, bute si jist, e s vaimi odpovmi budeme nakldat velice dvrn a dnm zpsobem neovlivn vae hodnocen.<P>Dkujeme za peliv a uven vyplnn tohoto dotaznku. Vae odpovdi nm pomohou vylepit online vuku tohoto kurzu v budoucnosti.';
$string['collespname'] = 'COLLES (Pedstavy)';
$string['done'] = 'Hotovo';
$string['download'] = 'Sthnout';
$string['downloadexcel'] = 'Sthnout data ve formtu tabulky Excel';
$string['downloadinfo'] = 'Mte monost sthnout daje zjitn tmto dotaznkem pro dal zpracovn v Excelu, SPSS nebo jinm programu.';
$string['downloadtext'] = 'Sthnout jako obyejn textov soubor';
$string['editingasurvey'] = 'prava przkumu';
$string['guestsnotallowed'] = 'Hostm nen dovoleno zastnit se przkum';
$string['helpsurveys'] = 'Npovda k rznm typm przkum';
$string['howlong'] = 'Jak dlouho vm trvalo vyplnn tohoto dotaznku?';
$string['howlongoptions'] = 'mn ne 1 minutu,1-2 minuty,2-3 minuty,3-4 minuty,4-5-minut,5-10 minut,vce ne 10 minut';
$string['ifoundthat'] = 'Zjistil jsem, e';
$string['introtext'] = 'vodn text';
$string['ipreferthat'] = 'Pedstavoval bych si, e';
$string['modulename'] = 'Przkum';
$string['modulenameplural'] = 'Przkumy';
$string['name'] = 'Jmno';
$string['newsurveyresponses'] = 'Nov odpovdi v przkumu';
$string['nobodyyet'] = 'Dosud se nikdo nezastnil tohoto przkumu';
$string['notdone'] = 'Zatm nedokoneno';
$string['notes'] = 'Vae soukrom postehy a poznmky';
$string['othercomments'] = 'Mte njak dal pipomnky?';
$string['peoplecompleted'] = '$a se zatm zastnilo tohoto przkumu';
$string['preferred'] = 'Pedstavy';
$string['preferredclass'] = 'Cel tda - pedstavy';
$string['preferredstudent'] = '$a - pedstavy';
$string['question'] = 'Otzka';
$string['questions'] = 'Otzky';
$string['questionsnotanswered'] = 'Nebyly zodpovzeny nkter otzky.';
$string['report'] = 'Zprva przkumu';
$string['savednotes'] = 'Vae poznmky byly uloeny';
$string['scaleagree5'] = 'Zcela nesouhlasm,sten nesouhlasm,Nemohu ci,sten souhlasm,Zcela souhlasm';
$string['scales'] = 'kly';
$string['scaletimes5'] = 'Tm nikdy,Zdka,Nkdy,asto,Tm vdy';
$string['seemoredetail'] = 'Vce podrobnost...';
$string['selectedquestions'] = 'Vybran odpovdi ze kly, vichni ci';
$string['summary'] = 'Souhrn';
$string['surveycompleted'] = 'Tento dotaznk jste ji vyplnili. Nsledujc graf zobrazuje souhrn vaich odpovd ve srovnn s prmrem cel tdy.';
$string['surveyname'] = 'Nzev przkumu';
$string['surveysaved'] = 'Przkum uloen';
$string['surveytype'] = 'Typ przkumu';
$string['thanksforanswers'] = 'Dkujeme za vyplnn tohoto dotaznku, $a';
$string['time'] = 'as';
$string['viewsurveyresponses'] = 'Zobrazit $a vyplnnch odpovd';

?>
